\name{DandD}
\alias{DandD}
\title{Import DandD Instance into \R}
\description{
   Function to import a DandD instance into \R as a \code{dad} object
}
\usage{
   DandD(file="", prefix="http://www.stat.math.keio.ac.jp/DandDIII/Examples/",
			 radix=FALSE, language="English")
}
\arguments{
  \item{file}{character. the name of a DandD instance. Possible examples of DandD instances 
are shown by default.}
  \item{prefix}{character.  URL for the file.}
  \item{radix}{logical,  indicatin if any radix system should
  be kept as is.  
  If ``TRUE'',  any radix system is not resolved into a vector  }
  \item{language}{character. Choice of language (currently ignored).}
}
\value{
 \code{dad} object.
}
\details{
\code{DandD} loads a DandD instance and returns a \code{dad} object.
The \code{dad} object is a list of every components of <Data>  in the DandD instance.
At loading,  any data vector in the DandD instance is transformed into
a function call,  so that application of the function \code{eval} is necessary 
to get the actual values.

The \code{dad} object returned by this function can be transformed into several dataframes
by applying the function \code{data.frame} to each element of the \code{dad} object 
as shown in the following example, or attached to the R search path
by using \code{attachDandD} as a promise object, that is, a delayed evaluation object.
The latter mechanism is automatically invoked by the print method 
\code{print.dad} for \code{dad} object.

\code{dad} object has its own \code{\link{plot}} method which
produces an appropriate graphical representation of the object.
see also \code{combineRadix}.
}
\seealso{
 \code{\link{openConn}}
 \code{\link{closeConn}}
 \code{\link{radix}}
}

\examples{\dontrun{

acid=DandD("AcidRain.dad")   # import a DandD instance and assign it to acid.
acid                         # print the dad object automatically attached.
acid$AcidRan$SlftCcn         # call object
eval(acid$AcidRan$SlftCcn)   # get actual values.
SlftCcn                      # access the promise object attached to the R search path.
acid.d=data.frame(acid[[1]]) # coerce to data frame.
acid.d
plot(acid)                   # produce plots
}
}
\keyword{dad}
\keyword{DandD}
\keyword{open}

\eof
\name{attachDandD}
\title{Attach Set of DandD Objects to Search Path}
\usage{
attachDandD(dad)
}
\alias{attachDandD}
\arguments{
  \item{dad}{``dad'' object, created by \code{\link{DandD}}.}
}
\description{
  Any components defined in <Data>  of the DandD instance corresponding to 
 the given ``dad'' object are attached to the \R search path.  
  This means that any data vector organized in <Data> are searched by \R when   evaluating a variable.  Usually, this function is called implicitly by \print
  method for dad object.

\details{
  By attaching a ``dad'' object to the search path, it is possible to refer 
  to each data vector organized in <Data> by their abbreviated names alone.
  Such abbreviated names can be identified to the LongName simply by
  typing the name of the ``dad object''.  Otherwise, explicit specification of
  each vector like \code{eval(obj$women$height)}) is required.

  By default an components in <Data > are attached in position 2 and later
  in the search path, immediately after the user's workspace and before all
  previously loaded packages and previously attached databases. 
}
\value{
  The \code{\link{environments}} are returned invisibly with 
  \code{"name"} attributes .
}
\references{
}
\seealso{
  \code{\link{DandD}}, \code{\link{attach}}, 
  \code{\link{library}}, \code{\link{detach}}, \code{\link{search}},
  \code{\link{objects}}, \code{\link{environment}}.
}
\examples{
acidRain=DandD("AcidRain.dad")
search()
attachDandD(acidRain)
search()
}
\keyword{data}

\eof
\name{connections}
\alias{openConn}
\alias{closeConn}
\title{Functions to Open and Close Connection to a DandD Server}
\description{
  Functions to open and close connection to a DandD Server.
  Usually this function is implicitly called by the function DandD.
}
\usage{
openConn(address = Server$address)
closeConn()
}
\arguments{
  \item{address}{IP Address of DandD Server.  By default it is set 
  the ``address'' component  of the current DandD Server descriptor 
  \code{.Server} stored
  in ``package:dad'' environment.}
}
\details{
  \code{openConn} creates a socket and establish a connection to 
  the specified DandD Server.  
  If the connection is successful,  the ``connected'' component is created in
  the current DandD Server descriptor \code{.Server}.
}
\seealso{
  \code{\link{DandD}}, \code{\link{setDandDServer}}.
}

\examples{
library(dad)
.Server #  ` `.Server$connected'' is null.
openConn()
.Server # If the connection were not successful,   ``.Server$connected'' is null.
}
\keyword{DandD}
\keyword{connection}
\keyword{dad}
\keyword{open}
\keyword{close}

\eof
\name{createInstance}
\alias{createInstance}
\title{Create DandD instance on DandD Server}
\description{
  Function to create a DandD instance on the current DandD Server.
}
\usage{
createInstance(dataFrame)
}
\arguments{
  \item{dataFrame}{\code{data.frame} object.}
}
\details{
  This function creates a new DandD instance which reflects the dataframe
  \code{dataFrame}  on the current DandD Server.
}
\seealso{
  \code{\link{DandD}}, \code{\link{getInstance}}.
}

\examples{
test.d=data.frame(v1=c(1,2),v2=c("a","b"))
createInstance(test.d)
getInstance()
}
\keyword{DandD}
\keyword{dad}
\keyword{open}
\keyword{close}

\eof
\name{getInstance}
\alias{getInstance}
\title{Get DandD instance from DandD Server}
\description{
  Function to get DandD instance loaded on DandD Server as a text.
}
\usage{
getInstance(file = NULL)
}
\arguments{
  \item{file}{character string naming an output file. If null, the console}
}
\details{
 The DandD instance loaded on the current eDandD Server is flushed
  as a text file.
}
\seealso{
  \code{\link{DandD}}, \code{\link{createInstance}}.
}

\examples{
obj=DandD("AcidRain.dad")  #``AcidRain.dad'' is loaded on DandD Server
getInstance()  #  the current DandD instance is flused out to the console 
}
\keyword{DandD}
\keyword{dad}
\keyword{open}
\keyword{close}

\eof
\name{setDandDServer}
\alias{setDandDServer}
\title{Set IP Address of DandD Server}
\description{
  Function to set the IP Address of a DandD Server.
}
\usage{
setDandDServer(address = "131.113.65.15")
}
\arguments{
  \item{address}{ IP Address or the address name of a DandD Server}
}
\details{
  This function will set a default IP address of DandD Server.
  It is stored in the server descriptor \code{.Server}
  stored in \code{package:dad} environment.  It will be used as
  the default address to the function \code{OpenConn}.
}

\value{
  IP Address of DandD Server ( a character string ) .
}
\seealso{
  \code{\link{DandD}}, \code{\link{openConn}}, \code{\link{closeConn}}.
}

\examples{
library(dad)
.Server
setDandDServer("127.0.0.1")
.Server
}
\keyword{DandD}
\keyword{dad}
\keyword{open}
\keyword{close}

\eof
